import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { S3ControlClientResolvedConfig } from "../S3ControlClient";
/**
 * @internal
 */
export interface S3ControlHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface S3ControlHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<S3ControlClientResolvedConfig, HandlerExecutionContext, S3ControlHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultS3ControlHttpAuthSchemeParametersProvider: (config: S3ControlClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<S3ControlHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface S3ControlHttpAuthSchemeProvider extends HttpAuthSchemeProvider<S3ControlHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultS3ControlHttpAuthSchemeProvider: S3ControlHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: S3ControlHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: S3ControlHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
