import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { DeleteAccessGrantsLocationRequest } from "../models/models_0";
import { S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../S3ControlClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteAccessGrantsLocationCommand}.
 */
export interface DeleteAccessGrantsLocationCommandInput extends DeleteAccessGrantsLocationRequest {
}
/**
 * @public
 *
 * The output of {@link DeleteAccessGrantsLocationCommand}.
 */
export interface DeleteAccessGrantsLocationCommandOutput extends __MetadataBearer {
}
declare const DeleteAccessGrantsLocationCommand_base: {
    new (input: DeleteAccessGrantsLocationCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteAccessGrantsLocationCommandInput, DeleteAccessGrantsLocationCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DeleteAccessGrantsLocationCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteAccessGrantsLocationCommandInput, DeleteAccessGrantsLocationCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Deregisters a location from your S3 Access Grants instance. You can only delete a location registration from an S3 Access Grants instance if there are no grants associated with this location. See <a href="https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessGrant.html">Delete a grant</a> for information on how to delete grants. You need to have at least one registered location in your S3 Access Grants instance in order to create access grants. </p>
 *          <dl>
 *             <dt>Permissions</dt>
 *             <dd>
 *                <p>You must have the <code>s3:DeleteAccessGrantsLocation</code> permission to use this operation. </p>
 *             </dd>
 *          </dl>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { S3ControlClient, DeleteAccessGrantsLocationCommand } from "@aws-sdk/client-s3-control"; // ES Modules import
 * // const { S3ControlClient, DeleteAccessGrantsLocationCommand } = require("@aws-sdk/client-s3-control"); // CommonJS import
 * const client = new S3ControlClient(config);
 * const input = { // DeleteAccessGrantsLocationRequest
 *   AccountId: "STRING_VALUE",
 *   AccessGrantsLocationId: "STRING_VALUE", // required
 * };
 * const command = new DeleteAccessGrantsLocationCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DeleteAccessGrantsLocationCommandInput - {@link DeleteAccessGrantsLocationCommandInput}
 * @returns {@link DeleteAccessGrantsLocationCommandOutput}
 * @see {@link DeleteAccessGrantsLocationCommandInput} for command's `input` shape.
 * @see {@link DeleteAccessGrantsLocationCommandOutput} for command's `response` shape.
 * @see {@link S3ControlClientResolvedConfig | config} for S3ControlClient's `config` shape.
 *
 * @throws {@link S3ControlServiceException}
 * <p>Base exception class for all service exceptions from S3Control service.</p>
 *
 * @public
 */
export declare class DeleteAccessGrantsLocationCommand extends DeleteAccessGrantsLocationCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeleteAccessGrantsLocationRequest;
            output: {};
        };
        sdk: {
            input: DeleteAccessGrantsLocationCommandInput;
            output: DeleteAccessGrantsLocationCommandOutput;
        };
    };
}
