import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { DissociateAccessGrantsIdentityCenterRequest } from "../models/models_0";
import { S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../S3ControlClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DissociateAccessGrantsIdentityCenterCommand}.
 */
export interface DissociateAccessGrantsIdentityCenterCommandInput extends DissociateAccessGrantsIdentityCenterRequest {
}
/**
 * @public
 *
 * The output of {@link DissociateAccessGrantsIdentityCenterCommand}.
 */
export interface DissociateAccessGrantsIdentityCenterCommandOutput extends __MetadataBearer {
}
declare const DissociateAccessGrantsIdentityCenterCommand_base: {
    new (input: DissociateAccessGrantsIdentityCenterCommandInput): import("@smithy/smithy-client").CommandImpl<DissociateAccessGrantsIdentityCenterCommandInput, DissociateAccessGrantsIdentityCenterCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [DissociateAccessGrantsIdentityCenterCommandInput]): import("@smithy/smithy-client").CommandImpl<DissociateAccessGrantsIdentityCenterCommandInput, DissociateAccessGrantsIdentityCenterCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Dissociates the Amazon Web Services IAM Identity Center instance from the S3 Access Grants instance. </p>
 *          <dl>
 *             <dt>Permissions</dt>
 *             <dd>
 *                <p>You must have the <code>s3:DissociateAccessGrantsIdentityCenter</code> permission to use this operation. </p>
 *             </dd>
 *             <dt>Additional Permissions</dt>
 *             <dd>
 *                <p>You must have the <code>sso:DeleteApplication</code> permission to use this operation. </p>
 *             </dd>
 *          </dl>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { S3ControlClient, DissociateAccessGrantsIdentityCenterCommand } from "@aws-sdk/client-s3-control"; // ES Modules import
 * // const { S3ControlClient, DissociateAccessGrantsIdentityCenterCommand } = require("@aws-sdk/client-s3-control"); // CommonJS import
 * const client = new S3ControlClient(config);
 * const input = { // DissociateAccessGrantsIdentityCenterRequest
 *   AccountId: "STRING_VALUE",
 * };
 * const command = new DissociateAccessGrantsIdentityCenterCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DissociateAccessGrantsIdentityCenterCommandInput - {@link DissociateAccessGrantsIdentityCenterCommandInput}
 * @returns {@link DissociateAccessGrantsIdentityCenterCommandOutput}
 * @see {@link DissociateAccessGrantsIdentityCenterCommandInput} for command's `input` shape.
 * @see {@link DissociateAccessGrantsIdentityCenterCommandOutput} for command's `response` shape.
 * @see {@link S3ControlClientResolvedConfig | config} for S3ControlClient's `config` shape.
 *
 * @throws {@link S3ControlServiceException}
 * <p>Base exception class for all service exceptions from S3Control service.</p>
 *
 * @public
 */
export declare class DissociateAccessGrantsIdentityCenterCommand extends DissociateAccessGrantsIdentityCenterCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DissociateAccessGrantsIdentityCenterRequest;
            output: {};
        };
        sdk: {
            input: DissociateAccessGrantsIdentityCenterCommandInput;
            output: DissociateAccessGrantsIdentityCenterCommandOutput;
        };
    };
}
