import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { GetAccessGrantsInstanceResourcePolicyRequest, GetAccessGrantsInstanceResourcePolicyResult } from "../models/models_0";
import { S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../S3ControlClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link GetAccessGrantsInstanceResourcePolicyCommand}.
 */
export interface GetAccessGrantsInstanceResourcePolicyCommandInput extends GetAccessGrantsInstanceResourcePolicyRequest {
}
/**
 * @public
 *
 * The output of {@link GetAccessGrantsInstanceResourcePolicyCommand}.
 */
export interface GetAccessGrantsInstanceResourcePolicyCommandOutput extends GetAccessGrantsInstanceResourcePolicyResult, __MetadataBearer {
}
declare const GetAccessGrantsInstanceResourcePolicyCommand_base: {
    new (input: GetAccessGrantsInstanceResourcePolicyCommandInput): import("@smithy/smithy-client").CommandImpl<GetAccessGrantsInstanceResourcePolicyCommandInput, GetAccessGrantsInstanceResourcePolicyCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [GetAccessGrantsInstanceResourcePolicyCommandInput]): import("@smithy/smithy-client").CommandImpl<GetAccessGrantsInstanceResourcePolicyCommandInput, GetAccessGrantsInstanceResourcePolicyCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Returns the resource policy of the S3 Access Grants instance. </p>
 *          <dl>
 *             <dt>Permissions</dt>
 *             <dd>
 *                <p>You must have the <code>s3:GetAccessGrantsInstanceResourcePolicy</code> permission to use this operation. </p>
 *             </dd>
 *          </dl>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { S3ControlClient, GetAccessGrantsInstanceResourcePolicyCommand } from "@aws-sdk/client-s3-control"; // ES Modules import
 * // const { S3ControlClient, GetAccessGrantsInstanceResourcePolicyCommand } = require("@aws-sdk/client-s3-control"); // CommonJS import
 * const client = new S3ControlClient(config);
 * const input = { // GetAccessGrantsInstanceResourcePolicyRequest
 *   AccountId: "STRING_VALUE",
 * };
 * const command = new GetAccessGrantsInstanceResourcePolicyCommand(input);
 * const response = await client.send(command);
 * // { // GetAccessGrantsInstanceResourcePolicyResult
 * //   Policy: "STRING_VALUE",
 * //   Organization: "STRING_VALUE",
 * //   CreatedAt: new Date("TIMESTAMP"),
 * // };
 *
 * ```
 *
 * @param GetAccessGrantsInstanceResourcePolicyCommandInput - {@link GetAccessGrantsInstanceResourcePolicyCommandInput}
 * @returns {@link GetAccessGrantsInstanceResourcePolicyCommandOutput}
 * @see {@link GetAccessGrantsInstanceResourcePolicyCommandInput} for command's `input` shape.
 * @see {@link GetAccessGrantsInstanceResourcePolicyCommandOutput} for command's `response` shape.
 * @see {@link S3ControlClientResolvedConfig | config} for S3ControlClient's `config` shape.
 *
 * @throws {@link S3ControlServiceException}
 * <p>Base exception class for all service exceptions from S3Control service.</p>
 *
 * @public
 */
export declare class GetAccessGrantsInstanceResourcePolicyCommand extends GetAccessGrantsInstanceResourcePolicyCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: GetAccessGrantsInstanceResourcePolicyRequest;
            output: GetAccessGrantsInstanceResourcePolicyResult;
        };
        sdk: {
            input: GetAccessGrantsInstanceResourcePolicyCommandInput;
            output: GetAccessGrantsInstanceResourcePolicyCommandOutput;
        };
    };
}
