import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { GetAccessGrantsLocationRequest, GetAccessGrantsLocationResult } from "../models/models_0";
import { S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../S3ControlClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link GetAccessGrantsLocationCommand}.
 */
export interface GetAccessGrantsLocationCommandInput extends GetAccessGrantsLocationRequest {
}
/**
 * @public
 *
 * The output of {@link GetAccessGrantsLocationCommand}.
 */
export interface GetAccessGrantsLocationCommandOutput extends GetAccessGrantsLocationResult, __MetadataBearer {
}
declare const GetAccessGrantsLocationCommand_base: {
    new (input: GetAccessGrantsLocationCommandInput): import("@smithy/smithy-client").CommandImpl<GetAccessGrantsLocationCommandInput, GetAccessGrantsLocationCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: GetAccessGrantsLocationCommandInput): import("@smithy/smithy-client").CommandImpl<GetAccessGrantsLocationCommandInput, GetAccessGrantsLocationCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Retrieves the details of a particular location registered in your S3 Access Grants instance. </p>
 *          <dl>
 *             <dt>Permissions</dt>
 *             <dd>
 *                <p>You must have the <code>s3:GetAccessGrantsLocation</code> permission to use this operation. </p>
 *             </dd>
 *          </dl>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { S3ControlClient, GetAccessGrantsLocationCommand } from "@aws-sdk/client-s3-control"; // ES Modules import
 * // const { S3ControlClient, GetAccessGrantsLocationCommand } = require("@aws-sdk/client-s3-control"); // CommonJS import
 * const client = new S3ControlClient(config);
 * const input = { // GetAccessGrantsLocationRequest
 *   AccountId: "STRING_VALUE",
 *   AccessGrantsLocationId: "STRING_VALUE", // required
 * };
 * const command = new GetAccessGrantsLocationCommand(input);
 * const response = await client.send(command);
 * // { // GetAccessGrantsLocationResult
 * //   CreatedAt: new Date("TIMESTAMP"),
 * //   AccessGrantsLocationId: "STRING_VALUE",
 * //   AccessGrantsLocationArn: "STRING_VALUE",
 * //   LocationScope: "STRING_VALUE",
 * //   IAMRoleArn: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param GetAccessGrantsLocationCommandInput - {@link GetAccessGrantsLocationCommandInput}
 * @returns {@link GetAccessGrantsLocationCommandOutput}
 * @see {@link GetAccessGrantsLocationCommandInput} for command's `input` shape.
 * @see {@link GetAccessGrantsLocationCommandOutput} for command's `response` shape.
 * @see {@link S3ControlClientResolvedConfig | config} for S3ControlClient's `config` shape.
 *
 * @throws {@link S3ControlServiceException}
 * <p>Base exception class for all service exceptions from S3Control service.</p>
 *
 * @public
 */
export declare class GetAccessGrantsLocationCommand extends GetAccessGrantsLocationCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: GetAccessGrantsLocationRequest;
            output: GetAccessGrantsLocationResult;
        };
        sdk: {
            input: GetAccessGrantsLocationCommandInput;
            output: GetAccessGrantsLocationCommandOutput;
        };
    };
}
