import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { GetBucketRequest, GetBucketResult } from "../models/models_0";
import { S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../S3ControlClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link GetBucketCommand}.
 */
export interface GetBucketCommandInput extends GetBucketRequest {
}
/**
 * @public
 *
 * The output of {@link GetBucketCommand}.
 */
export interface GetBucketCommandOutput extends GetBucketResult, __MetadataBearer {
}
declare const GetBucketCommand_base: {
    new (input: GetBucketCommandInput): import("@smithy/smithy-client").CommandImpl<GetBucketCommandInput, GetBucketCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: GetBucketCommandInput): import("@smithy/smithy-client").CommandImpl<GetBucketCommandInput, GetBucketCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Gets an Amazon S3 on Outposts bucket. For more information, see <a href="https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3onOutposts.html"> Using Amazon S3 on Outposts</a> in the
 *             <i>Amazon S3 User Guide</i>.</p>
 *          <p>If you are using an identity other than the root user of the Amazon Web Services account that owns the
 *          Outposts bucket, the calling identity must have the <code>s3-outposts:GetBucket</code>
 *          permissions on the specified Outposts bucket and belong to the Outposts bucket owner's
 *          account in order to use this action. Only users from Outposts bucket owner account with
 *          the right permissions can perform actions on an Outposts bucket. </p>
 *          <p>If you don't have <code>s3-outposts:GetBucket</code> permissions or you're not using an
 *          identity that belongs to the bucket owner's account, Amazon S3 returns a <code>403 Access
 *             Denied</code> error.</p>
 *          <p>The following actions are related to <code>GetBucket</code> for Amazon S3 on Outposts:</p>
 *          <p>All Amazon S3 on Outposts REST API requests for this action require an additional parameter of <code>x-amz-outpost-id</code> to be passed with the request. In addition, you must use an S3 on Outposts endpoint hostname prefix instead of <code>s3-control</code>. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and the <code>x-amz-outpost-id</code> derived by using the access point ARN, see the <a href="https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucket.html#API_control_GetBucket_Examples">Examples</a> section.</p>
 *          <ul>
 *             <li>
 *                <p>
 *                   <a href="https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html">PutObject</a>
 *                </p>
 *             </li>
 *             <li>
 *                <p>
 *                   <a href="https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateBucket.html">CreateBucket</a>
 *                </p>
 *             </li>
 *             <li>
 *                <p>
 *                   <a href="https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteBucket.html">DeleteBucket</a>
 *                </p>
 *             </li>
 *          </ul>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { S3ControlClient, GetBucketCommand } from "@aws-sdk/client-s3-control"; // ES Modules import
 * // const { S3ControlClient, GetBucketCommand } = require("@aws-sdk/client-s3-control"); // CommonJS import
 * const client = new S3ControlClient(config);
 * const input = { // GetBucketRequest
 *   AccountId: "STRING_VALUE",
 *   Bucket: "STRING_VALUE", // required
 * };
 * const command = new GetBucketCommand(input);
 * const response = await client.send(command);
 * // { // GetBucketResult
 * //   Bucket: "STRING_VALUE",
 * //   PublicAccessBlockEnabled: true || false,
 * //   CreationDate: new Date("TIMESTAMP"),
 * // };
 *
 * ```
 *
 * @param GetBucketCommandInput - {@link GetBucketCommandInput}
 * @returns {@link GetBucketCommandOutput}
 * @see {@link GetBucketCommandInput} for command's `input` shape.
 * @see {@link GetBucketCommandOutput} for command's `response` shape.
 * @see {@link S3ControlClientResolvedConfig | config} for S3ControlClient's `config` shape.
 *
 * @throws {@link S3ControlServiceException}
 * <p>Base exception class for all service exceptions from S3Control service.</p>
 *
 * @public
 */
export declare class GetBucketCommand extends GetBucketCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: GetBucketRequest;
            output: GetBucketResult;
        };
        sdk: {
            input: GetBucketCommandInput;
            output: GetBucketCommandOutput;
        };
    };
}
