import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { GetMultiRegionAccessPointPolicyRequest, GetMultiRegionAccessPointPolicyResult } from "../models/models_0";
import { S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../S3ControlClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link GetMultiRegionAccessPointPolicyCommand}.
 */
export interface GetMultiRegionAccessPointPolicyCommandInput extends GetMultiRegionAccessPointPolicyRequest {
}
/**
 * @public
 *
 * The output of {@link GetMultiRegionAccessPointPolicyCommand}.
 */
export interface GetMultiRegionAccessPointPolicyCommandOutput extends GetMultiRegionAccessPointPolicyResult, __MetadataBearer {
}
declare const GetMultiRegionAccessPointPolicyCommand_base: {
    new (input: GetMultiRegionAccessPointPolicyCommandInput): import("@smithy/smithy-client").CommandImpl<GetMultiRegionAccessPointPolicyCommandInput, GetMultiRegionAccessPointPolicyCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: GetMultiRegionAccessPointPolicyCommandInput): import("@smithy/smithy-client").CommandImpl<GetMultiRegionAccessPointPolicyCommandInput, GetMultiRegionAccessPointPolicyCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <note>
 *             <p>This operation is not supported by directory buckets.</p>
 *          </note>
 *          <p>Returns the access control policy of the specified Multi-Region Access Point.</p>
 *          <p>This action will always be routed to the US West (Oregon) Region. For more information
 *          about the restrictions around working with Multi-Region Access Points, see <a href="https://docs.aws.amazon.com/AmazonS3/latest/userguide/MultiRegionAccessPointRestrictions.html">Multi-Region Access Point
 *             restrictions and limitations</a> in the <i>Amazon S3 User Guide</i>.</p>
 *          <p>The following actions are related to
 *          <code>GetMultiRegionAccessPointPolicy</code>:</p>
 *          <ul>
 *             <li>
 *                <p>
 *                   <a href="https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetMultiRegionAccessPointPolicyStatus.html">GetMultiRegionAccessPointPolicyStatus</a>
 *                </p>
 *             </li>
 *             <li>
 *                <p>
 *                   <a href="https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutMultiRegionAccessPointPolicy.html">PutMultiRegionAccessPointPolicy</a>
 *                </p>
 *             </li>
 *          </ul>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { S3ControlClient, GetMultiRegionAccessPointPolicyCommand } from "@aws-sdk/client-s3-control"; // ES Modules import
 * // const { S3ControlClient, GetMultiRegionAccessPointPolicyCommand } = require("@aws-sdk/client-s3-control"); // CommonJS import
 * const client = new S3ControlClient(config);
 * const input = { // GetMultiRegionAccessPointPolicyRequest
 *   AccountId: "STRING_VALUE",
 *   Name: "STRING_VALUE", // required
 * };
 * const command = new GetMultiRegionAccessPointPolicyCommand(input);
 * const response = await client.send(command);
 * // { // GetMultiRegionAccessPointPolicyResult
 * //   Policy: { // MultiRegionAccessPointPolicyDocument
 * //     Established: { // EstablishedMultiRegionAccessPointPolicy
 * //       Policy: "STRING_VALUE",
 * //     },
 * //     Proposed: { // ProposedMultiRegionAccessPointPolicy
 * //       Policy: "STRING_VALUE",
 * //     },
 * //   },
 * // };
 *
 * ```
 *
 * @param GetMultiRegionAccessPointPolicyCommandInput - {@link GetMultiRegionAccessPointPolicyCommandInput}
 * @returns {@link GetMultiRegionAccessPointPolicyCommandOutput}
 * @see {@link GetMultiRegionAccessPointPolicyCommandInput} for command's `input` shape.
 * @see {@link GetMultiRegionAccessPointPolicyCommandOutput} for command's `response` shape.
 * @see {@link S3ControlClientResolvedConfig | config} for S3ControlClient's `config` shape.
 *
 * @throws {@link S3ControlServiceException}
 * <p>Base exception class for all service exceptions from S3Control service.</p>
 *
 * @public
 */
export declare class GetMultiRegionAccessPointPolicyCommand extends GetMultiRegionAccessPointPolicyCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: GetMultiRegionAccessPointPolicyRequest;
            output: GetMultiRegionAccessPointPolicyResult;
        };
        sdk: {
            input: GetMultiRegionAccessPointPolicyCommandInput;
            output: GetMultiRegionAccessPointPolicyCommandOutput;
        };
    };
}
