import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ListAccessGrantsLocationsRequest, ListAccessGrantsLocationsResult } from "../models/models_0";
import { S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../S3ControlClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListAccessGrantsLocationsCommand}.
 */
export interface ListAccessGrantsLocationsCommandInput extends ListAccessGrantsLocationsRequest {
}
/**
 * @public
 *
 * The output of {@link ListAccessGrantsLocationsCommand}.
 */
export interface ListAccessGrantsLocationsCommandOutput extends ListAccessGrantsLocationsResult, __MetadataBearer {
}
declare const ListAccessGrantsLocationsCommand_base: {
    new (input: ListAccessGrantsLocationsCommandInput): import("@smithy/smithy-client").CommandImpl<ListAccessGrantsLocationsCommandInput, ListAccessGrantsLocationsCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [ListAccessGrantsLocationsCommandInput]): import("@smithy/smithy-client").CommandImpl<ListAccessGrantsLocationsCommandInput, ListAccessGrantsLocationsCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Returns a list of the locations registered in your S3 Access Grants instance.</p>
 *          <dl>
 *             <dt>Permissions</dt>
 *             <dd>
 *                <p>You must have the <code>s3:ListAccessGrantsLocations</code> permission to use this operation. </p>
 *             </dd>
 *          </dl>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { S3ControlClient, ListAccessGrantsLocationsCommand } from "@aws-sdk/client-s3-control"; // ES Modules import
 * // const { S3ControlClient, ListAccessGrantsLocationsCommand } = require("@aws-sdk/client-s3-control"); // CommonJS import
 * const client = new S3ControlClient(config);
 * const input = { // ListAccessGrantsLocationsRequest
 *   AccountId: "STRING_VALUE",
 *   NextToken: "STRING_VALUE",
 *   MaxResults: Number("int"),
 *   LocationScope: "STRING_VALUE",
 * };
 * const command = new ListAccessGrantsLocationsCommand(input);
 * const response = await client.send(command);
 * // { // ListAccessGrantsLocationsResult
 * //   NextToken: "STRING_VALUE",
 * //   AccessGrantsLocationsList: [ // AccessGrantsLocationsList
 * //     { // ListAccessGrantsLocationsEntry
 * //       CreatedAt: new Date("TIMESTAMP"),
 * //       AccessGrantsLocationId: "STRING_VALUE",
 * //       AccessGrantsLocationArn: "STRING_VALUE",
 * //       LocationScope: "STRING_VALUE",
 * //       IAMRoleArn: "STRING_VALUE",
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param ListAccessGrantsLocationsCommandInput - {@link ListAccessGrantsLocationsCommandInput}
 * @returns {@link ListAccessGrantsLocationsCommandOutput}
 * @see {@link ListAccessGrantsLocationsCommandInput} for command's `input` shape.
 * @see {@link ListAccessGrantsLocationsCommandOutput} for command's `response` shape.
 * @see {@link S3ControlClientResolvedConfig | config} for S3ControlClient's `config` shape.
 *
 * @throws {@link S3ControlServiceException}
 * <p>Base exception class for all service exceptions from S3Control service.</p>
 *
 * @public
 */
export declare class ListAccessGrantsLocationsCommand extends ListAccessGrantsLocationsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListAccessGrantsLocationsRequest;
            output: ListAccessGrantsLocationsResult;
        };
        sdk: {
            input: ListAccessGrantsLocationsCommandInput;
            output: ListAccessGrantsLocationsCommandOutput;
        };
    };
}
