import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ListCallerAccessGrantsRequest, ListCallerAccessGrantsResult } from "../models/models_0";
import { S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../S3ControlClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListCallerAccessGrantsCommand}.
 */
export interface ListCallerAccessGrantsCommandInput extends ListCallerAccessGrantsRequest {
}
/**
 * @public
 *
 * The output of {@link ListCallerAccessGrantsCommand}.
 */
export interface ListCallerAccessGrantsCommandOutput extends ListCallerAccessGrantsResult, __MetadataBearer {
}
declare const ListCallerAccessGrantsCommand_base: {
    new (input: ListCallerAccessGrantsCommandInput): import("@smithy/smithy-client").CommandImpl<ListCallerAccessGrantsCommandInput, ListCallerAccessGrantsCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [ListCallerAccessGrantsCommandInput]): import("@smithy/smithy-client").CommandImpl<ListCallerAccessGrantsCommandInput, ListCallerAccessGrantsCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Returns a list of the access grants that were given to the caller using S3 Access Grants and that allow the caller to access the S3 data of the Amazon Web Services account specified in the request.</p>
 *          <dl>
 *             <dt>Permissions</dt>
 *             <dd>
 *                <p>You must have the <code>s3:ListCallerAccessGrants</code> permission to use this operation. </p>
 *             </dd>
 *          </dl>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { S3ControlClient, ListCallerAccessGrantsCommand } from "@aws-sdk/client-s3-control"; // ES Modules import
 * // const { S3ControlClient, ListCallerAccessGrantsCommand } = require("@aws-sdk/client-s3-control"); // CommonJS import
 * const client = new S3ControlClient(config);
 * const input = { // ListCallerAccessGrantsRequest
 *   AccountId: "STRING_VALUE",
 *   GrantScope: "STRING_VALUE",
 *   NextToken: "STRING_VALUE",
 *   MaxResults: Number("int"),
 *   AllowedByApplication: true || false,
 * };
 * const command = new ListCallerAccessGrantsCommand(input);
 * const response = await client.send(command);
 * // { // ListCallerAccessGrantsResult
 * //   NextToken: "STRING_VALUE",
 * //   CallerAccessGrantsList: [ // CallerAccessGrantsList
 * //     { // ListCallerAccessGrantsEntry
 * //       Permission: "READ" || "WRITE" || "READWRITE",
 * //       GrantScope: "STRING_VALUE",
 * //       ApplicationArn: "STRING_VALUE",
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param ListCallerAccessGrantsCommandInput - {@link ListCallerAccessGrantsCommandInput}
 * @returns {@link ListCallerAccessGrantsCommandOutput}
 * @see {@link ListCallerAccessGrantsCommandInput} for command's `input` shape.
 * @see {@link ListCallerAccessGrantsCommandOutput} for command's `response` shape.
 * @see {@link S3ControlClientResolvedConfig | config} for S3ControlClient's `config` shape.
 *
 * @throws {@link S3ControlServiceException}
 * <p>Base exception class for all service exceptions from S3Control service.</p>
 *
 * @public
 */
export declare class ListCallerAccessGrantsCommand extends ListCallerAccessGrantsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListCallerAccessGrantsRequest;
            output: ListCallerAccessGrantsResult;
        };
        sdk: {
            input: ListCallerAccessGrantsCommandInput;
            output: ListCallerAccessGrantsCommandOutput;
        };
    };
}
