import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ListRegionalBucketsRequest, ListRegionalBucketsResult } from "../models/models_0";
import { S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../S3ControlClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListRegionalBucketsCommand}.
 */
export interface ListRegionalBucketsCommandInput extends ListRegionalBucketsRequest {
}
/**
 * @public
 *
 * The output of {@link ListRegionalBucketsCommand}.
 */
export interface ListRegionalBucketsCommandOutput extends ListRegionalBucketsResult, __MetadataBearer {
}
declare const ListRegionalBucketsCommand_base: {
    new (input: ListRegionalBucketsCommandInput): import("@smithy/smithy-client").CommandImpl<ListRegionalBucketsCommandInput, ListRegionalBucketsCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [ListRegionalBucketsCommandInput]): import("@smithy/smithy-client").CommandImpl<ListRegionalBucketsCommandInput, ListRegionalBucketsCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <note>
 *             <p>This operation is not supported by directory buckets.</p>
 *          </note>
 *          <p>Returns a list of all Outposts buckets in an Outpost that are owned by the authenticated
 *          sender of the request. For more information, see <a href="https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3onOutposts.html">Using Amazon S3 on Outposts</a> in the
 *             <i>Amazon S3 User Guide</i>.</p>
 *          <p>For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts
 *          endpoint hostname prefix and <code>x-amz-outpost-id</code> in your request, see the <a href="https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListRegionalBuckets.html#API_control_ListRegionalBuckets_Examples">Examples</a> section.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { S3ControlClient, ListRegionalBucketsCommand } from "@aws-sdk/client-s3-control"; // ES Modules import
 * // const { S3ControlClient, ListRegionalBucketsCommand } = require("@aws-sdk/client-s3-control"); // CommonJS import
 * const client = new S3ControlClient(config);
 * const input = { // ListRegionalBucketsRequest
 *   AccountId: "STRING_VALUE",
 *   NextToken: "STRING_VALUE",
 *   MaxResults: Number("int"),
 *   OutpostId: "STRING_VALUE",
 * };
 * const command = new ListRegionalBucketsCommand(input);
 * const response = await client.send(command);
 * // { // ListRegionalBucketsResult
 * //   RegionalBucketList: [ // RegionalBucketList
 * //     { // RegionalBucket
 * //       Bucket: "STRING_VALUE", // required
 * //       BucketArn: "STRING_VALUE",
 * //       PublicAccessBlockEnabled: true || false, // required
 * //       CreationDate: new Date("TIMESTAMP"), // required
 * //       OutpostId: "STRING_VALUE",
 * //     },
 * //   ],
 * //   NextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListRegionalBucketsCommandInput - {@link ListRegionalBucketsCommandInput}
 * @returns {@link ListRegionalBucketsCommandOutput}
 * @see {@link ListRegionalBucketsCommandInput} for command's `input` shape.
 * @see {@link ListRegionalBucketsCommandOutput} for command's `response` shape.
 * @see {@link S3ControlClientResolvedConfig | config} for S3ControlClient's `config` shape.
 *
 * @throws {@link S3ControlServiceException}
 * <p>Base exception class for all service exceptions from S3Control service.</p>
 *
 * @public
 */
export declare class ListRegionalBucketsCommand extends ListRegionalBucketsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListRegionalBucketsRequest;
            output: ListRegionalBucketsResult;
        };
        sdk: {
            input: ListRegionalBucketsCommandInput;
            output: ListRegionalBucketsCommandOutput;
        };
    };
}
