import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { PutAccessGrantsInstanceResourcePolicyRequest, PutAccessGrantsInstanceResourcePolicyResult } from "../models/models_1";
import { S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../S3ControlClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link PutAccessGrantsInstanceResourcePolicyCommand}.
 */
export interface PutAccessGrantsInstanceResourcePolicyCommandInput extends PutAccessGrantsInstanceResourcePolicyRequest {
}
/**
 * @public
 *
 * The output of {@link PutAccessGrantsInstanceResourcePolicyCommand}.
 */
export interface PutAccessGrantsInstanceResourcePolicyCommandOutput extends PutAccessGrantsInstanceResourcePolicyResult, __MetadataBearer {
}
declare const PutAccessGrantsInstanceResourcePolicyCommand_base: {
    new (input: PutAccessGrantsInstanceResourcePolicyCommandInput): import("@smithy/smithy-client").CommandImpl<PutAccessGrantsInstanceResourcePolicyCommandInput, PutAccessGrantsInstanceResourcePolicyCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: PutAccessGrantsInstanceResourcePolicyCommandInput): import("@smithy/smithy-client").CommandImpl<PutAccessGrantsInstanceResourcePolicyCommandInput, PutAccessGrantsInstanceResourcePolicyCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Updates the resource policy of the S3 Access Grants instance. </p>
 *          <dl>
 *             <dt>Permissions</dt>
 *             <dd>
 *                <p>You must have the <code>s3:PutAccessGrantsInstanceResourcePolicy</code> permission to use this operation. </p>
 *             </dd>
 *          </dl>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { S3ControlClient, PutAccessGrantsInstanceResourcePolicyCommand } from "@aws-sdk/client-s3-control"; // ES Modules import
 * // const { S3ControlClient, PutAccessGrantsInstanceResourcePolicyCommand } = require("@aws-sdk/client-s3-control"); // CommonJS import
 * const client = new S3ControlClient(config);
 * const input = { // PutAccessGrantsInstanceResourcePolicyRequest
 *   AccountId: "STRING_VALUE",
 *   Policy: "STRING_VALUE", // required
 *   Organization: "STRING_VALUE",
 * };
 * const command = new PutAccessGrantsInstanceResourcePolicyCommand(input);
 * const response = await client.send(command);
 * // { // PutAccessGrantsInstanceResourcePolicyResult
 * //   Policy: "STRING_VALUE",
 * //   Organization: "STRING_VALUE",
 * //   CreatedAt: new Date("TIMESTAMP"),
 * // };
 *
 * ```
 *
 * @param PutAccessGrantsInstanceResourcePolicyCommandInput - {@link PutAccessGrantsInstanceResourcePolicyCommandInput}
 * @returns {@link PutAccessGrantsInstanceResourcePolicyCommandOutput}
 * @see {@link PutAccessGrantsInstanceResourcePolicyCommandInput} for command's `input` shape.
 * @see {@link PutAccessGrantsInstanceResourcePolicyCommandOutput} for command's `response` shape.
 * @see {@link S3ControlClientResolvedConfig | config} for S3ControlClient's `config` shape.
 *
 * @throws {@link S3ControlServiceException}
 * <p>Base exception class for all service exceptions from S3Control service.</p>
 *
 * @public
 */
export declare class PutAccessGrantsInstanceResourcePolicyCommand extends PutAccessGrantsInstanceResourcePolicyCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: PutAccessGrantsInstanceResourcePolicyRequest;
            output: PutAccessGrantsInstanceResourcePolicyResult;
        };
        sdk: {
            input: PutAccessGrantsInstanceResourcePolicyCommandInput;
            output: PutAccessGrantsInstanceResourcePolicyCommandOutput;
        };
    };
}
