import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { UpdateJobPriorityRequest, UpdateJobPriorityResult } from "../models/models_1";
import { S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../S3ControlClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link UpdateJobPriorityCommand}.
 */
export interface UpdateJobPriorityCommandInput extends UpdateJobPriorityRequest {
}
/**
 * @public
 *
 * The output of {@link UpdateJobPriorityCommand}.
 */
export interface UpdateJobPriorityCommandOutput extends UpdateJobPriorityResult, __MetadataBearer {
}
declare const UpdateJobPriorityCommand_base: {
    new (input: UpdateJobPriorityCommandInput): import("@smithy/smithy-client").CommandImpl<UpdateJobPriorityCommandInput, UpdateJobPriorityCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: UpdateJobPriorityCommandInput): import("@smithy/smithy-client").CommandImpl<UpdateJobPriorityCommandInput, UpdateJobPriorityCommandOutput, S3ControlClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Updates an existing S3 Batch Operations job's priority. For more information, see <a href="https://docs.aws.amazon.com/AmazonS3/latest/userguide/batch-ops.html">S3 Batch Operations</a> in the <i>Amazon S3 User Guide</i>.</p>
 *          <dl>
 *             <dt>Permissions</dt>
 *             <dd>
 *                <p>To use the
 *                   <code>UpdateJobPriority</code> operation, you must have permission to
 *                   perform the <code>s3:UpdateJobPriority</code> action.</p>
 *             </dd>
 *          </dl>
 *          <p>Related actions include:</p>
 *          <ul>
 *             <li>
 *                <p>
 *                   <a href="https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateJob.html">CreateJob</a>
 *                </p>
 *             </li>
 *             <li>
 *                <p>
 *                   <a href="https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListJobs.html">ListJobs</a>
 *                </p>
 *             </li>
 *             <li>
 *                <p>
 *                   <a href="https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DescribeJob.html">DescribeJob</a>
 *                </p>
 *             </li>
 *             <li>
 *                <p>
 *                   <a href="https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_UpdateJobStatus.html">UpdateJobStatus</a>
 *                </p>
 *             </li>
 *          </ul>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { S3ControlClient, UpdateJobPriorityCommand } from "@aws-sdk/client-s3-control"; // ES Modules import
 * // const { S3ControlClient, UpdateJobPriorityCommand } = require("@aws-sdk/client-s3-control"); // CommonJS import
 * const client = new S3ControlClient(config);
 * const input = { // UpdateJobPriorityRequest
 *   AccountId: "STRING_VALUE",
 *   JobId: "STRING_VALUE", // required
 *   Priority: Number("int"), // required
 * };
 * const command = new UpdateJobPriorityCommand(input);
 * const response = await client.send(command);
 * // { // UpdateJobPriorityResult
 * //   JobId: "STRING_VALUE", // required
 * //   Priority: Number("int"), // required
 * // };
 *
 * ```
 *
 * @param UpdateJobPriorityCommandInput - {@link UpdateJobPriorityCommandInput}
 * @returns {@link UpdateJobPriorityCommandOutput}
 * @see {@link UpdateJobPriorityCommandInput} for command's `input` shape.
 * @see {@link UpdateJobPriorityCommandOutput} for command's `response` shape.
 * @see {@link S3ControlClientResolvedConfig | config} for S3ControlClient's `config` shape.
 *
 * @throws {@link BadRequestException} (client fault)
 *  <p></p>
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p></p>
 *
 * @throws {@link NotFoundException} (client fault)
 *  <p></p>
 *
 * @throws {@link TooManyRequestsException} (client fault)
 *  <p></p>
 *
 * @throws {@link S3ControlServiceException}
 * <p>Base exception class for all service exceptions from S3Control service.</p>
 *
 * @public
 */
export declare class UpdateJobPriorityCommand extends UpdateJobPriorityCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: UpdateJobPriorityRequest;
            output: UpdateJobPriorityResult;
        };
        sdk: {
            input: UpdateJobPriorityCommandInput;
            output: UpdateJobPriorityCommandOutput;
        };
    };
}
