import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import {
  BucketVersioningStatus,
  JobStatus,
  LifecycleRule,
  MultiRegionAccessPointRoute,
  ObjectLambdaConfiguration,
  PublicAccessBlockConfiguration,
  PutMultiRegionAccessPointPolicyInput,
  ReplicationConfiguration,
  S3Tag,
  StorageLensConfiguration,
  StorageLensGroup,
  StorageLensTag,
  Tag,
} from "./models_0";
import { S3ControlServiceException as __BaseException } from "./S3ControlServiceException";
export interface ListStorageLensConfigurationEntry {
  Id: string | undefined;
  StorageLensArn: string | undefined;
  HomeRegion: string | undefined;
  IsEnabled?: boolean;
}
export interface ListStorageLensConfigurationsResult {
  NextToken?: string;
  StorageLensConfigurationList?: ListStorageLensConfigurationEntry[];
}
export interface ListStorageLensGroupsRequest {
  AccountId?: string;
  NextToken?: string;
}
export interface ListStorageLensGroupEntry {
  Name: string | undefined;
  StorageLensGroupArn: string | undefined;
  HomeRegion: string | undefined;
}
export interface ListStorageLensGroupsResult {
  NextToken?: string;
  StorageLensGroupList?: ListStorageLensGroupEntry[];
}
export interface ListTagsForResourceRequest {
  AccountId?: string;
  ResourceArn: string | undefined;
}
export interface ListTagsForResourceResult {
  Tags?: Tag[];
}
export interface PutAccessGrantsInstanceResourcePolicyRequest {
  AccountId?: string;
  Policy: string | undefined;
  Organization?: string;
}
export interface PutAccessGrantsInstanceResourcePolicyResult {
  Policy?: string;
  Organization?: string;
  CreatedAt?: Date;
}
export interface PutAccessPointConfigurationForObjectLambdaRequest {
  AccountId?: string;
  Name: string | undefined;
  Configuration: ObjectLambdaConfiguration | undefined;
}
export interface PutAccessPointPolicyRequest {
  AccountId?: string;
  Name: string | undefined;
  Policy: string | undefined;
}
export interface PutAccessPointPolicyForObjectLambdaRequest {
  AccountId?: string;
  Name: string | undefined;
  Policy: string | undefined;
}
export interface LifecycleConfiguration {
  Rules?: LifecycleRule[];
}
export interface PutBucketLifecycleConfigurationRequest {
  AccountId?: string;
  Bucket: string | undefined;
  LifecycleConfiguration?: LifecycleConfiguration;
}
export interface PutBucketPolicyRequest {
  AccountId?: string;
  Bucket: string | undefined;
  ConfirmRemoveSelfBucketAccess?: boolean;
  Policy: string | undefined;
}
export interface PutBucketReplicationRequest {
  AccountId?: string;
  Bucket: string | undefined;
  ReplicationConfiguration: ReplicationConfiguration | undefined;
}
export interface Tagging {
  TagSet: S3Tag[] | undefined;
}
export interface PutBucketTaggingRequest {
  AccountId?: string;
  Bucket: string | undefined;
  Tagging: Tagging | undefined;
}
export declare const MFADelete: {
  readonly Disabled: "Disabled";
  readonly Enabled: "Enabled";
};
export type MFADelete = (typeof MFADelete)[keyof typeof MFADelete];
export interface VersioningConfiguration {
  MFADelete?: MFADelete;
  Status?: BucketVersioningStatus;
}
export interface PutBucketVersioningRequest {
  AccountId?: string;
  Bucket: string | undefined;
  MFA?: string;
  VersioningConfiguration: VersioningConfiguration | undefined;
}
export interface PutJobTaggingRequest {
  AccountId?: string;
  JobId: string | undefined;
  Tags: S3Tag[] | undefined;
}
export interface PutJobTaggingResult {}
export declare class TooManyTagsException extends __BaseException {
  readonly name: "TooManyTagsException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<TooManyTagsException, __BaseException>
  );
}
export interface PutMultiRegionAccessPointPolicyRequest {
  AccountId?: string;
  ClientToken?: string;
  Details: PutMultiRegionAccessPointPolicyInput | undefined;
}
export interface PutMultiRegionAccessPointPolicyResult {
  RequestTokenARN?: string;
}
export interface PutPublicAccessBlockRequest {
  PublicAccessBlockConfiguration: PublicAccessBlockConfiguration | undefined;
  AccountId?: string;
}
export interface PutStorageLensConfigurationRequest {
  ConfigId: string | undefined;
  AccountId?: string;
  StorageLensConfiguration: StorageLensConfiguration | undefined;
  Tags?: StorageLensTag[];
}
export interface PutStorageLensConfigurationTaggingRequest {
  ConfigId: string | undefined;
  AccountId?: string;
  Tags: StorageLensTag[] | undefined;
}
export interface PutStorageLensConfigurationTaggingResult {}
export interface SubmitMultiRegionAccessPointRoutesRequest {
  AccountId?: string;
  Mrap: string | undefined;
  RouteUpdates: MultiRegionAccessPointRoute[] | undefined;
}
export interface SubmitMultiRegionAccessPointRoutesResult {}
export interface TagResourceRequest {
  AccountId?: string;
  ResourceArn: string | undefined;
  Tags: Tag[] | undefined;
}
export interface TagResourceResult {}
export interface UntagResourceRequest {
  AccountId?: string;
  ResourceArn: string | undefined;
  TagKeys: string[] | undefined;
}
export interface UntagResourceResult {}
export interface UpdateAccessGrantsLocationRequest {
  AccountId?: string;
  AccessGrantsLocationId: string | undefined;
  IAMRoleArn: string | undefined;
}
export interface UpdateAccessGrantsLocationResult {
  CreatedAt?: Date;
  AccessGrantsLocationId?: string;
  AccessGrantsLocationArn?: string;
  LocationScope?: string;
  IAMRoleArn?: string;
}
export interface UpdateJobPriorityRequest {
  AccountId?: string;
  JobId: string | undefined;
  Priority: number | undefined;
}
export interface UpdateJobPriorityResult {
  JobId: string | undefined;
  Priority: number | undefined;
}
export declare class JobStatusException extends __BaseException {
  readonly name: "JobStatusException";
  readonly $fault: "client";
  Message?: string;
  constructor(opts: __ExceptionOptionType<JobStatusException, __BaseException>);
}
export declare const RequestedJobStatus: {
  readonly Cancelled: "Cancelled";
  readonly Ready: "Ready";
};
export type RequestedJobStatus =
  (typeof RequestedJobStatus)[keyof typeof RequestedJobStatus];
export interface UpdateJobStatusRequest {
  AccountId?: string;
  JobId: string | undefined;
  RequestedJobStatus: RequestedJobStatus | undefined;
  StatusUpdateReason?: string;
}
export interface UpdateJobStatusResult {
  JobId?: string;
  Status?: JobStatus;
  StatusUpdateReason?: string;
}
export interface UpdateStorageLensGroupRequest {
  Name: string | undefined;
  AccountId?: string;
  StorageLensGroup: StorageLensGroup | undefined;
}
